You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@directory.apache.org by ak...@apache.org on 2009/08/24 13:45:06 UTC

svn commit: r807161 - /directory/shared/branches/shared-schema/ldap/src/main/java/org/apache/directory/shared/ldap/schema/registries/SchemaObjectRegistry.java

Author: akarasulu
Date: Mon Aug 24 11:45:05 2009
New Revision: 807161

URL: http://svn.apache.org/viewvc?rev=807161&view=rev
Log:
doco corrections 

Modified:
    directory/shared/branches/shared-schema/ldap/src/main/java/org/apache/directory/shared/ldap/schema/registries/SchemaObjectRegistry.java

Modified: directory/shared/branches/shared-schema/ldap/src/main/java/org/apache/directory/shared/ldap/schema/registries/SchemaObjectRegistry.java
URL: http://svn.apache.org/viewvc/directory/shared/branches/shared-schema/ldap/src/main/java/org/apache/directory/shared/ldap/schema/registries/SchemaObjectRegistry.java?rev=807161&r1=807160&r2=807161&view=diff
==============================================================================
--- directory/shared/branches/shared-schema/ldap/src/main/java/org/apache/directory/shared/ldap/schema/registries/SchemaObjectRegistry.java (original)
+++ directory/shared/branches/shared-schema/ldap/src/main/java/org/apache/directory/shared/ldap/schema/registries/SchemaObjectRegistry.java Mon Aug 24 11:45:05 2009
@@ -50,21 +50,21 @@
     /** a map of Normalizers looked up by OID or Name */
     protected final Map<String, T> byOid;
     
-    /** maps an OID to a SchemaObject Description */
-    private final Map<String, U> oidToDescription;
+    /** maps an OID to a SchemaObject specification */
+    private final Map<String, U> oidToSpecification;
 
     
     /** The SchemaObject type */
     protected SchemaObjectType type;
-    
-    
+
+
     /**
      * Creates a new SchemaObjectRegistry instance.
      */
     protected SchemaObjectRegistry( SchemaObjectType schemaObjectType )
     {
         byOid = new ConcurrentHashMap<String, T>();
-        oidToDescription = new ConcurrentHashMap<String, U>();
+        oidToSpecification = new ConcurrentHashMap<String, U>();
         type = schemaObjectType;
     }
     
@@ -127,7 +127,7 @@
             if ( originalSchemaName.equalsIgnoreCase( schemaObject.getSchemaName() ) )
             {
                 schemaObject.setSchemaName( newSchemaName );
-                SchemaObject description = oidToDescription.get( schemaObject.getOid() );
+                SchemaObject description = oidToSpecification.get( schemaObject.getOid() );
                 
                 if ( description != null )
                 {
@@ -170,9 +170,9 @@
      *
      * @return an Iterator of descriptions
      */
-    public Iterator<U> descriptionsIterator()
+    public Iterator<U> specificationsIterator()
     {
-        return oidToDescription.values().iterator();
+        return oidToSpecification.values().iterator();
     }
 
     
@@ -233,12 +233,12 @@
     /**
      * Registers a new SchemaObject with this registry.
      *
      * @param schemaObjectDescription The SchemaObject description to register
      * @param schemaObject the SchemaObject to register
      * @throws NamingException if the SchemaObject is already registered or
      * the registration operation is not supported
      */
-    public void register( U schemaObjectDescription, T schemaObject ) throws NamingException
+    public void register( U schemaObjectSpecification, T schemaObject ) throws NamingException
     {
         String oid = schemaObject.getOid();
         
@@ -262,7 +262,7 @@
         }
         
         // And register the description too
-        oidToDescription.put( oid, schemaObjectDescription );
+        oidToSpecification.put( oid, schemaObjectSpecification );
         
         if ( DEBUG )
         {
@@ -233,12 +233,12 @@
      * Registers a new SchemaObject with this registry.
      *
-     * @param schemaObjectDescription The SchemaObject description to register
+     * @param schemaObjectSpecification The SchemaObject description to register
      * @param schemaObject the SchemaObject to register
      * @throws NamingException if the SchemaObject is already registered or